from abc import ABC, abstractmethod


class NextcloudSyncWorkerConfiguration(ABC):
    """Nextcloud sync worker configuration interface."""

    @abstractmethod
    def get_nextcloud_endpoint(self) -> str:
        """Get Nextcloud endpoint.

        :return: Endpoint
        :rtype: str
        """
        raise NotImplementedError()

    @abstractmethod
    def set_nextcloud_endpoint(self, value: str) -> None:
        """Set Nextcloud endpoint.

        :param str value: New value
        """
        raise NotImplementedError()

    @abstractmethod
    def get_nextcloud_username(self) -> str:
        """Get Nextcloud username.

        :return: Username
        :rtype: str
        """
        raise NotImplementedError()

    @abstractmethod
    def set_nextcloud_username(self, value: str) -> None:
        """Set Nextcloud username.

        :param str value: New value
        """
        raise NotImplementedError()

    @abstractmethod
    def get_nextcloud_prune_threshold(self) -> int:
        """Get Nextcloud prune threshold.

        :return: Threshold
        :rtype: int
        """
        raise NotImplementedError()

    @abstractmethod
    def set_nextcloud_prune_threshold(self, value: int) -> None:
        """Set Nextcloud prune threshold.

        :param int value: New value
        """
        raise NotImplementedError()
